@@ -162,6 +162,7 @@ typedef struct gss_cred_id_desc_struct {
     gss_name_desc *                     globusid;
     gss_cred_usage_t                    cred_usage;
     SSL_CTX *                           ssl_context;
+    gss_OID                             mech;
 } gss_cred_id_desc;
 
 typedef struct gss_ctx_id_desc_struct{
@@ -175,6 +176,7 @@ typedef struct gss_ctx_id_desc_struct{
     OM_uint32                           req_flags;
     OM_uint32                           ctx_flags;
     int                                 cred_obtained;
+    gss_OID                             mech;
 #if OPENSSL_VERSION_NUMBER >= 0x10000100L
     /** For GCM ciphers, sequence number of next read MAC token */
     uint64_t                            mac_read_sequence;
@@ -201,6 +203,9 @@ typedef struct gss_ctx_id_desc_struct{
 extern
 const gss_OID_desc * const              gss_mech_globus_gssapi_openssl;
 
+extern
+const gss_OID_desc * const              gss_mech_globus_gssapi_openssl_micv2;
+
 extern
 const gss_OID_desc * const              gss_proxycertinfo_extension;
 
